# Changelog

## 0.0.1-alpha.1 (2024-08-02)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/EndexAI/factset-events-and-transcripts-api-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* configure new SDK language ([7f12382](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/7f12382e93781864a8a2feeac71279bb0df733a1))
* go live ([#1](https://github.com/EndexAI/factset-events-and-transcripts-api-python/issues/1)) ([6caa15e](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/6caa15edd26431d0a49f25e73fdec475cc98da18))
